OC.L10N.register(
    "dav",
    {
    "Calendar" : "Naptár",
    "Tasks" : "Feladatok",
    "Personal" : "Személyes",
    "{actor} created calendar {calendar}" : "{actor} létrehozta a naptárt: {calendar}",
    "You created calendar {calendar}" : "Létrehozta a naptárt: {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} törölte a naptárt: {calendar}",
    "You deleted calendar {calendar}" : "Törölte a naptárt: {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} frissítette a naptárt: {calendar}",
    "You updated calendar {calendar}" : "Frissítette a naptárt: {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} helyreállította a naptárt: {calendar}",
    "You restored calendar {calendar}" : "Helyreállította a naptárt: {calendar}",
    "You shared calendar {calendar} as public link" : "Nyilvános hivatkozásként osztotta meg a naptárt: {calendar}",
    "You removed public link for calendar {calendar}" : "Eltávolította a naptár nyilvános hivatkozását: {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} megosztotta Önnel a naptárt: {calendar}",
    "You shared calendar {calendar} with {user}" : "Megosztotta a(z) {calendar} naptárt a következővel: {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} megosztotta a(z) {calendar} naptárt a következővel: {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} visszavonta Öntől a(z) {calendar} naptár megosztását",
    "You unshared calendar {calendar} from {user}" : "Visszavonta a(z) {calendar} naptár megosztását a következőtől: {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} visszavonta a(z) {calendar} naptár megosztását a következőtől: {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} visszavonta saját magától a(z) {calendar} naptár megosztását",
    "You shared calendar {calendar} with group {group}" : "Megosztotta a(z) {calendar} naptárt a következő csoporttal: {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} megosztotta a(z) {calendar} naptárt a következő csoporttal: {group}",
    "You unshared calendar {calendar} from group {group}" : "Visszavonta a(z) {calendar} naptár magosztását a következő csoporttól: {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} visszavonta a(z) {calendar} naptár megosztását a következő csoporttól: {group}",
    "Untitled event" : "Névtelen esemény",
    "{actor} created event {event} in calendar {calendar}" : "{actor} létrehozta a(z) {event} eseményt a következő naptárban: {calendar}",
    "You created event {event} in calendar {calendar}" : "Létrehozta a(z) {event} eseményt a következő naptárban: {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} törölte a(z) {event} eseményt a következő naptárból: {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Törölte a(z) {event} eseményt a következő naptárból: {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} frissítette a(z) {event} eseményt a következő naptárban: {calendar}",
    "You updated event {event} in calendar {calendar}" : "Frissítette a(z) {event} eseményt a következő naptárban: {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} áthelyezte a(z) {event} eseményt a(z) {sourceCalendar} naptárból a(z) {targetCalendar} naptárba",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Áthelyezte a(z) {event} eseményt a(z) {sourceCalendar} naptárból a(z) {targetCalendar} naptárba",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} helyreállította a(z) {calendar} naptár következő eseményét: {event}",
    "You restored event {event} of calendar {calendar}" : "Helyreállította a(z) {calendar} naptár következő eseményét: {event}",
    "Busy" : "Foglalt",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} létrehozta a(z) {todo} teendőt a következő listában: {calendar}",
    "You created to-do {todo} in list {calendar}" : "Létrehozta a(z) {todo} teendőt a következő listában: {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} törölte a(z) {todo} teendőt a következő listából: {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Törölte a(z) {todo} teendőt a következő listából: {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} frissítette a(z) {todo} teendőt a következő listában: {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Frissítette a(z) {todo} teendőt a következő listában: {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} elintézte a(z) {todo} teendőt a következő listában: {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Elintézte a(z) {todo} teendőt a következő listában: {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} újranyitotta a(z) {todo} teendőt a következő listában: {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Újranyitotta a(z) {todo} teendőt a következő listában: {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} áthelyezte a(z) {todo} teendőt a(z) {sourceCalendar} listából a(z) {targetCalendar} listába",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Áthelyezte a(z) {todo} teendőt a(z) {sourceCalendar} listából a(z) {targetCalendar} listába",
    "Calendar, contacts and tasks" : "Naptár, címjegyzék és feladatok",
    "A <strong>calendar</strong> was modified" : "Egy <strong>naptár</strong> megváltozott",
    "A calendar <strong>event</strong> was modified" : "Egy <strong>naptáresemény</strong> megváltozott",
    "A calendar <strong>to-do</strong> was modified" : "Egy <strong>naptárteendő</strong> megváltozott",
    "Contact birthdays" : "Névjegyek születésnapjai",
    "Death of %s" : "%s halála",
    "Untitled calendar" : "Névtelen naptár",
    "Calendar:" : "Naptár:",
    "Date:" : "Dátum:",
    "Where:" : "Hol:",
    "Description:" : "Leírás:",
    "_%n year_::_%n years_" : ["%n év","%n év"],
    "_%n month_::_%n months_" : ["%n hónap","%n hónap"],
    "_%n day_::_%n days_" : ["%n nap","%n nap"],
    "_%n hour_::_%n hours_" : ["%n óra","%n óra"],
    "_%n minute_::_%n minutes_" : ["%n perc","%n perc"],
    "%s (in %s)" : "%s (%s múlva)",
    "%s (%s ago)" : "%s (ennyi ideje: %s)",
    "Calendar: %s" : "Naptár: %s",
    "Date: %s" : "Dátum: %s",
    "Description: %s" : "Leírás: %s",
    "Where: %s" : "Hely: %s",
    "%1$s via %2$s" : "%1$s – %2$s",
    "Could not generate when statement" : "Nem sikerlt létrehozni a mikor állítást",
    "Every Day for the entire day" : "Minden Nap a teljes napra",
    "Every Day for the entire day until %1$s" : "Minden Nap a teljes napon eddig %1$s",
    "Every Day between %1$s - %2$s" : "Minden Nap %1$s - %2$sközött",
    "Every Day between %1$s - %2$s until %3$s" : "Minden Nap %1$s - %2$s között %3$s-ig",
    "Every %1$d Days for the entire day" : "Minden %1$d Nap az teljes napra",
    "Every %1$d Days for the entire day until %2$s" : "Minden%1$d Nap a teljes napra  %2$s-ig",
    "Every %1$d Days between %2$s - %3$s" : "Minden%1$d Nap %2$s - %3$s között",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Minden%1$d Napon %2$s - %3$s között %4$s-ig",
    "Could not generate event recurrence statement" : "Nem sikerült megújuló eseményt létrehozni",
    "Every Week on %1$s for the entire day" : "Minden hét %1$s napon a teljes napja",
    "Every Week on %1$s for the entire day until %2$s" : "Minden Héten %1$s a teljes napra %2$s-ig",
    "Every Week on %1$s between %2$s - %3$s" : "Minden Hét %1$s napján %2$s - %3$sközött",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Minden Hét %1$s napján %2$s - %3$s között %4$s-ig",
    "Every %1$d Weeks on %2$s for the entire day" : "Minden%1$d héten %2$s napon a teljes napra",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Minden%1$d Héten %2$s napján a teljes napon %3$s-ig",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Minden%1$d hét %2$s napján %3$s - %4$sközött",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Minden%1$d héten %2$s napján %3$s - %4$s között eddig %5$s",
    "Every Month on the %1$s for the entire day" : "Minden hónap %1$s napján a teljes napon",
    "Every Month on the %1$s for the entire day until %2$s" : "Minden hónap %1$s napján a teljes napon %2$s-ig",
    "Every Month on the %1$s between %2$s - %3$s" : "Minden hónap %1$s napján %2$sés %3$s között",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Minden hónap %1$s napján %2$sés %3$s között %4$s-ig",
    "Every %1$d Months on the %2$s for the entire day" : "Minden%1$d Hónap  %2$s napján a teljes napon",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Minden%1$d Hónap %2$s napján a teljes napon %3$s-ig",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Minden%1$d Hónap %2$s napján %3$s és %4$s között",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Minden%1$d Hónap %2$s napján %3$s és %4$s között %5$s-ig",
    "Every Year in %1$s on the %2$s for the entire day" : "Minden év %1$s hónap %2$s napján a teljes napra",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Minden év %1$s hónapjában %2$s napján a teljes napon %3$s-ig",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Minden év %1$s hónapjában %2$s napján %3$s - %4$sközött.",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Minden év %1$s hónapjában %2$s napján %3$s - %4$s között eddig %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Minden%1$d év %2$s hónapján %3$s napján a teljes napra",
    "On specific dates for the entire day until %1$s" : "Egy megadott időpontban a teljes napon %1$s-ig ",
    "On specific dates between %1$s - %2$s until %3$s" : "Egy megadott időpontban %1$s és %2$s %3$s-ig",
    "Could not generate next recurrence statement" : "Nem sikerült a következő megújuló eseményt létrehozni",
    "Cancelled: %1$s" : "Lemondva: %1$s",
    "\"%1$s\" has been canceled" : "A következőt le lett mondva: „%1$s”",
    "Re: %1$s" : "Vá: %1$s",
    "%1$s has accepted your invitation" : "%1$s elfogadta a meghívását",
    "%1$s has tentatively accepted your invitation" : "%1$s feltételesen elfogadta a meghívását",
    "%1$s has declined your invitation" : "%1$s elutasította a meghívását",
    "%1$s has responded to your invitation" : "%1$s válaszolt a meghívására",
    "Invitation updated: %1$s" : "Meghívó frissítve: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s frissítette a következő eseményt: %2$s",
    "Invitation: %1$s" : "Meghívó: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s meg szeretné hívni a következőre: „%2$s”",
    "Organizer:" : "Szervező:",
    "Attendees:" : "Résztvevők:",
    "Title:" : "Cím:",
    "When:" : "Mikor:",
    "Location:" : "Hely:",
    "Link:" : "Hivatkozás:",
    "Occurring:" : "Előforduló",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "More options …" : "További lehetőségek…",
    "More options at %s" : "További lehetőségek itt: %s",
    "Monday" : "Hétfő",
    "Tuesday" : "Kedd",
    "Wednesday" : "Szerda",
    "Thursday" : "Csütörtök",
    "Friday" : "Péntek",
    "Saturday" : "Szombat",
    "Sunday" : "Vasárnap",
    "January" : "Január",
    "February" : "Február",
    "March" : "Március",
    "April" : "Április",
    "May" : "Május",
    "June" : "Június",
    "July" : "Július",
    "August" : "Augusztus",
    "September" : "Szeptember",
    "October" : "Október",
    "November" : "November",
    "December" : "December",
    "First" : "Első",
    "Second" : "Másodperc",
    "Third" : "Harmadik",
    "Fourth" : "Negyedik",
    "Last" : "Utolsó",
    "Second Last" : "Második Utolsó",
    "Third Last" : "Harmadik Utolsó",
    "Fourth Last" : "Negyedik Utolsó",
    "Contacts" : "Névjegyek",
    "{actor} created address book {addressbook}" : "{actor} létrehozta a következő címjegyzéket: {addressbook}",
    "You created address book {addressbook}" : "Létrehozta a következő címjegyzéket: {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} törölte a következő címjegyzéket: {addressbook}",
    "You deleted address book {addressbook}" : "Törölte a következő címjegyzéket: {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} aktualizálta a következő címjegyzéket: {addressbook}",
    "You updated address book {addressbook}" : "Aktualizálta a következő címjegyzéket {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} megosztotta Önnel a következő címjegyzéket: {addressbook}",
    "You shared address book {addressbook} with {user}" : "Megosztotta a(z) {addressbook} címjegyzéket a következővel: {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} megosztotta a(z) {addressbook} címjegyzéket a következővel: {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} visszavonta Öntől a(z) {addressbook} címjegyzék megosztását",
    "You unshared address book {addressbook} from {user}" : "Visszavonta a(z) {addressbook} címjegyzék megosztását a következőtől: {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} visszavonta a(z) {addressbook} címjegyzék megosztását a következőtől: {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} visszavonta saját magától a(z) {addressbook} címjegyzék megosztását",
    "You shared address book {addressbook} with group {group}" : "Megosztotta a(z) {addressbook} címjegyzéket a következő csoporttal: {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} megosztotta a(z) {addressbook} címjegyzéket a következő csoporttal: {group}",
    "You unshared address book {addressbook} from group {group}" : "Visszavonta a(z) {addressbook} címjegyzék megosztását a következő csoporttól: {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} visszavonta a(z) {addressbook} címjegyzék megosztását a következő csoporttól: {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} létrehozta a(z) {card} névjegyet a következő címjegyzékben: {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Létrehozta a(z) {card} névjegyet a következő címjegyzékben: {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} törölte a(z) {card} névjegyet a következő címjegyzékből: {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Törölte a(z) {card} névjegyet a következő címjegyzékből: {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} aktualizálta a(z) {card} névjegyet a következő címjegyzékben: {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Aktualizálta a(z) {card} névjegyet a következő címjegyzékben: {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Egy <strong>névjegy</strong> vagy <strong>címjegyzék</strong> módosítva lett",
    "Accounts" : "Fiókok",
    "System address book which holds all accounts" : "A rendszer címjegyzéke, amely az összes fiókot tartalmazza",
    "File is not updatable: %1$s" : "A fájl nem frissíthető: %1$s",
    "Failed to get storage for file" : "Nem sikerlt a tárhely lekérése a fájl számára",
    "Could not write to final file, canceled by hook" : "A végleges fájl nem írható, a hurok megszakította",
    "Could not write file contents" : "A fájl tartalma nem írható",
    "_%n byte_::_%n bytes_" : ["%n bájt","%n bájt"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Hiba történt a fájl célhelyre másolása során (másolva: %1$s, várt fájlméret: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "A várt fájlméret %1$s, de %2$s lett beolvasva (a Nextcloud kliensből) és kiírva (a Nextcloud tárolóba). Ez lehet hálózati probléma a fájl küldése során, vagy írási hiba a tárolónál, a kiszolgáló oldalon.",
    "Could not rename part file to final file, canceled by hook" : "A részleges fájl nem nevezhető át a végleges fájllá, a hurok megszakította",
    "Could not rename part file to final file" : "A részleges fájl nem nevezhető át a végleges fájllá",
    "Failed to check file size: %1$s" : "A fájlméret nem ellenőrizhető: %1$s",
    "Encryption not ready: %1$s" : "A titkosítás nincs kész: %1$s",
    "Failed to open file: %1$s" : "A fájl megnyitása sikertelen: %1$s",
    "Failed to unlink: %1$s" : "A hivatkozás eltávolítása sikertelen: %1$s",
    "Failed to write file contents: %1$s" : "A fájl tartalmának kiírása sikertelen: %1$s",
    "File not found: %1$s" : "A fájl nem található: %1$s",
    "Invalid target path" : "Érvénytelen elérési útvonal",
    "System is in maintenance mode." : "A rendszer karbantartási módban van.",
    "Upgrade needed" : "Frissítés szükséges",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "A %s kiszolgálót HTTPS használatára kell beállítani, hogy iOS-szel/macOS-szel használhassa CalDAV-ot és a CardDAV-ot.",
    "Configures a CalDAV account" : "Beállítja a CalDAV-fiókot",
    "Configures a CardDAV account" : "Beállítja a CardDAV-fiókot",
    "Events" : "Események",
    "Untitled task" : "Névtelen feladat",
    "Completed on %s" : "Befejezve: %s",
    "Due on %s by %s" : "Esedékesség: %s, %s által",
    "Due on %s" : "Esedékesség: %s",
    "DAV system address book" : "DAV rendszer címjegyzék",
    "No outstanding DAV system address book sync." : "Nincs kiemelkedő DAV rendszer címjegyzék szinkronizálás.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "A DAV rendszer címjegyzék szinkronizációja még nem futott le, mert több, mint 1000 felhasználó található vagy hiba történt. Kérem futtassa manuálisan a következő paranccsal: \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "WebDAV végpont",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "A webkiszolgáló nincs megfelelően beállítva a fájlok szinkronizálásához, mert a WebDAV interfész hibásnak tűnik.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "A webkisolgáló megfelelően van konfigurálva a WebDAVon keresztüli fájl szinkronizáció engedélyezéséhez.",
    "Migrated calendar (%1$s)" : "Átköltöztetett naptár (%1$s)",
    "Calendars including events, details and attendees" : "Naptárak eseményekkel, részletekkel és résztvevőkkel",
    "Contacts and groups" : "Névjegyek és csoportok",
    "WebDAV" : "WebDAV",
    "First day" : "Első nap",
    "Last day (inclusive)" : "Utols nap (beleértve)",
    "Out of office replacement (optional)" : "Távolléti helyettesítő (opcionális)",
    "Name of the replacement" : "Helyettesítő neve",
    "No results." : "Nincs eredmény.",
    "Start typing." : "Kezdjen gépelni.",
    "Short absence status" : "Rövid távolléti állapot",
    "Long absence Message" : "Hosszú távolléti állapot",
    "Save" : "Mentés",
    "Disable absence" : "Távollét tiltása",
    "Absence saved" : "Távollét mentve",
    "Failed to save your absence settings" : "Nem sikerlt a távolléti beállítások mentése",
    "Absence cleared" : "Távollét törölve",
    "Failed to clear your absence settings" : "Nem sikerült a távolléti beállítások törlése",
    "Time zone:" : "Időzóna:",
    "to" : "–",
    "Delete slot" : "Idősáv törlése",
    "No working hours set" : "Nincs munkaidő beállítva",
    "Add slot" : "Idősáv hozzáadása",
    "Weekdays" : "Hétköznapok",
    "Pick a start time for {dayName}" : "Válassz kezdő dátumot a {dayName}-hoz",
    "Pick a end time for {dayName}" : "Válassz vége dátumot a {dayName}-hoz",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Az elérhetőségi időn túl, a felhasználói állapot automatikus beállítása „Ne zavarjanak” módba az összes értesítés némításához.",
    "Failed to load availability" : "Az elérhetőség betöltése sikertelen",
    "Saved availability" : "Elérhetőség mentve",
    "Failed to save availability" : "Az elérhetőség mentése sikertelen",
    "Availability" : "Elérhetőség",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ha beállítja a munkaidejét, akkor más emberek a megbeszélések létrehozásakor látni fogják, hogy Ön mikor nem érhető el.",
    "Absence" : "Távollét",
    "Configure your next absence period." : "A követkeő távolléti periódus beállítása.",
    "Calendar server" : "Naptárkiszolgáló",
    "Send invitations to attendees" : "Meghívó küldése a résztvevőknek",
    "Automatically generate a birthday calendar" : "Születésnapokat tartalmazó naptár automatikus létrehozása",
    "Birthday calendars will be generated by a background job." : "A születésnapokat tartalmazó naptárakat egy háttérben futó folyamat fogja létrehozni.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Nem lesznek elérhetők azonnal az engedélyezés után, de egy rövid idő múlva már láthatók lesznek.",
    "Send notifications for events" : "Értesítések küldése az eseményekről",
    "Notifications are sent via background jobs, so these must occur often enough." : "Az értesítéseket háttérfeladatok küldik, ezért ezeknek elég gyakran meg kell történniük.",
    "Send reminder notifications to calendar sharees as well" : "Emlékeztető értesítések küldése azoknak is, akikkel a naptár meg van osztva",
    "Reminders are always sent to organizers and attendees." : "Az értesítések mindig a szervezőknek és a résztvevőknek lesznek elküldve.",
    "Enable notifications for events via push" : "Leküldéses értesítések engedélyezése az eseményekhez",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Telepítse a {calendarappstoreopen}Naptár alkalmazást{linkclose}, vagy {calendardocopen}csatlakoztassa asztali számítógépét és mobilját a szinkronizáláshoz ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ne felejtse el megfelelően beállítani az {emailopen}e-mail kiszolgálót{linkclose}.",
    "There was an error updating your attendance status." : "Hiba történt a részvételi állapotának frissítése során.",
    "Please contact the organizer directly." : "Vegye fel a kapcsolatot közvetlenül a szervezővel.",
    "Are you accepting the invitation?" : "Elfogadja az meghívást?",
    "Tentative" : "Feltételes",
    "Your attendance was updated successfully." : "A részvétele frissítése sikeres.",
    "Time:" : "Idő:",
    "Could not open file" : "A fájl nem nyitható meg",
    "Invalid chunk name" : "Érvénytelen darabnév",
    "Could not rename part file assembled from chunks" : "Nem lehet átnevezni a darabokból összeállított részleges fájlt"
},
"nplurals=2; plural=(n != 1);");
